@@ -6,7 +6,7 @@
 ## This code is free software; you can redistribute it and/or modify
 ## it under the same terms as Perl itself.
 ##
-## $Id: Agent.pm,v 1.74 2004/06/14 23:12:06 vipul Exp $
+## $Id: Agent.pm,v 1.76 2004/12/03 21:45:58 vipul Exp $
 
 package Razor2::Client::Agent;
 
@@ -28,7 +28,6 @@ $PROTOCOL = $Razor2::Client::Version::PROTOCOL;
 $VERSION  = $Razor2::Client::Version::VERSION;
 
 
-
 sub new {
     my ($class, $breed) = @_;
 
@@ -57,7 +56,8 @@ sub new {
     my %me = (
             name_version => "Razor-Agents v$VERSION",  # used in register
             breed        => $1,
-            preproc      => new Razor2::Preproc::Manager,
+            preproc      => new Razor2::Preproc::Manager (no_deHTMLcomment => 1),
+            preproc_vr8  => new Razor2::Preproc::Manager (no_deHTML => 1),
             global_razorhome => '/etc/razor',
     );
     
@@ -696,6 +696,7 @@ sub reportit {
 
     my $objects = $self->prepare_objects($mails) or return 2;  
 
+
     # compute_sigs needs server info like ep4, so get_server_info first
     $self->get_server_info()                            or return 2;
 
