@@ -6,11 +6,10 @@
 ## This code is free software; you can redistribute it and/or modify
 ## it under the same terms as Perl itself.
 ##
-## $Id: Core.pm,v 1.73 2004/06/15 00:45:50 vipul Exp $
+## $Id: Core.pm,v 1.76 2004/12/03 21:44:56 vipul Exp $
 
 package Razor2::Client::Core;
 
-
     use strict;
     use IO::Socket;
     use IO::Select;
@@ -30,7 +29,7 @@ package Razor2::Client::Core;
                           fisher_yates_shuffle);
 
 
-($VERSION) = do { my @r = (q$Revision: 1.73 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+($VERSION) = do { my @r = (q$Revision: 1.76 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 $PROTOCOL = $Razor2::Client::Version::PROTOCOL; 
 
 
@@ -596,13 +595,25 @@ sub compute_sigs {
         #
         next unless $obj->{p};
         foreach my $objp (@{$obj->{p}}) {
-            next if $objp->{skipme};
 
+            next if $objp->{skipme};
             my $olen = length(${$objp->{body}});
             my $clnpart = ${$objp->{body}};
-            $self->{preproc}->preproc( \$clnpart ); # in da future: $self->{s}->{conf}->{dre}
+
+            # We'll do a VR8 preproc to determine emptiness
+            # of email, and store it so VR8 can use it.
+
+            my $clnpart_vr8 = $clnpart;
+            $self->{preproc_vr8}->preproc( \$clnpart_vr8 ); # in da future: $self->{s}->{conf}->{dre}
+            $objp->{cleaned_vr8} = \$clnpart_vr8;
+
+            # This for VR4 (the only other signature scheme
+            # supported at this time.
+
+            $self->{preproc}->preproc( \$clnpart ); 
             $objp->{cleaned} = \$clnpart;
-            my $clen = length($clnpart);
+
+            my $clen = length($clnpart_vr8);
 
             $self->log2file( 15, $objp->{body},    "$objp->{id}.before_preproc.as_reported");
             $self->log2file( 15, $objp->{cleaned}, "$objp->{id}.after_preproc");
@@ -611,11 +622,11 @@ sub compute_sigs {
                 $self->log(6,"preproc: mail $objp->{id} went from $olen bytes to 0, erasing");
                 $objp->{skipme} = 1;
                 next;
-	        } elsif (($clen < 128)and($clnpart =~ /^(Content\S*:[^\n]*\n\r?)+(Content\S*:[^\n]*)?\s*$/s)) {
+	        } elsif (($clen < 128) and ($clnpart =~ /^(Content\S*:[^\n]*\n\r?)+(Content\S*:[^\n]*)?\s*$/s)) {
                 $self->log(6,"preproc: mail $objp->{id} seems empty, erasing");
                 $objp->{skipme} = 1;
                 next;
-            } elsif ($clnpart !~ /\S/) {
+            } elsif ($clnpart_vr8 !~ /\S/) {
                 $self->log(6,"preproc: mail $objp->{id} went to all whitespace, erasing");
                 $objp->{skipme} = 1;
                 next;
@@ -685,7 +696,7 @@ sub compute_sigs {
                     
                     $sig = $self->compute_engine( 
                             $engine_no, 
-                            $objp->{body}
+                            $objp->{cleaned_vr8}
                     );  
 
                 } else {  
@@ -776,7 +787,7 @@ sub make_query {
         $query{ep4} = $params->{ep4} if $query{e} eq '4';
         return \%query;
 
-    } elsif ($params->{action} =~ /(report|revoke)/) {
+    } elsif ($params->{action} =~ /(report)/) {
 
         # prep_mail already truncated headers and body parts > 64K
         my @dudes;
@@ -807,6 +818,31 @@ sub make_query {
         }
         return @queries;
 
+    } elsif ($params->{action} =~ /revoke/) { 
+
+        # Never send messages on revoke. Revoke all signature
+        # that we were able to compute.
+
+        my $n = 0;
+        my @queries;
+        while ($params->{obj}->{p}->[$n]) {
+            for my $engine (keys %{$self->{s}->{engines}}) { 
+                my $sigs; 
+                if ($sigs = $params->{obj}->{p}->[$n]->{"e$engine"}) { 
+                    if (ref $sigs eq 'ARRAY') { 
+                        for my $sig (@$sigs) { 
+                            push @queries, {a => 'revoke', e => $engine, s => $sig};
+                        }
+                    } else { 
+                        push @queries, {a => 'revoke', e => $engine, s => $sigs};
+                    }
+                }
+            }
+            $n++;
+        }
+
+        return @queries;
+
     }
 
 }
@@ -1434,6 +1470,7 @@ sub report {
         # create new {sent} and add obj to @robjs
         #
         foreach my $obj (@$objs) {
+
             next if $obj->{skipme};
 
             #$self->log(12,"mail $obj->{id} read ". scalar(@{$obj->{resp}}) ." queries");
@@ -1970,7 +2007,7 @@ sub compute_server_conf {
         $self->log (6, "Ignore what engines server supports for -H");
         $self->{s}->{engines} = $self->compute_supported_engines();
     } else { 
-        my $se = hexbits2hash($self->{s}->{conf}->{se} );
+        my $se = hexbits2hash($self->{s}->{conf}->{se});
         $self->{s}->{engines} = $self->compute_supported_engines($se);
     } 
 }
