@@ -1,4 +1,4 @@
-# $Id: String.pm,v 1.46 2004/06/18 17:23:22 vipul Exp $
+# $Id: String.pm,v 1.47 2004/11/20 06:15:13 vipul Exp $
 package Razor2::String;
 
 use Digest::SHA1 qw(sha1_hex);
@@ -989,17 +989,13 @@ print "    Part: ", $ent->bodyhandle->path, " (", scalar($ent->head->mime_type),
 # output: hash ref or array containg bits that are set
 #         2D == (1, 3, 4, 6)
 
-sub hexbits2hash {
+sub hexbits2hash { 
+
     my $hex = shift;
-
     my %h;
-    my $i = 0;
-    foreach (reverse split '', unpack "B*", pack "H*", $hex) {
-        $i++;
-        $h{$i} = 1 if  $_ eq 1;
-    }
-
+    for (0..31) { if (hex($hex) & (2**31)>>(31-$_)) { $h{$_+1} = 1 } }
     return wantarray ? (sort keys %h) : \%h;
+
 }
 
 
